@@ -99,8 +99,10 @@ bool OnlySpaceOrTab(const std::string &s) noexcept {
 	return true;
 }
 
-std::vector<std::string> StringSplit(const std::string &text, int separator) {
-	std::vector<std::string> vs(text.empty() ? 0 : 1);
+using Tokens = std::vector<std::string>;
+
+Tokens StringSplit(const std::string &text, int separator) {
+	Tokens vs(text.empty() ? 0 : 1);
 	for (const char ch : text) {
 		if (ch == separator) {
 			vs.emplace_back();
@@ -112,33 +114,26 @@ std::vector<std::string> StringSplit(const std::string &text, int separator) {
 }
 
 struct BracketPair {
-	std::vector<std::string>::iterator itBracket;
-	std::vector<std::string>::iterator itEndBracket;
+	Tokens::iterator itBracket;
+	Tokens::iterator itEndBracket;
 };
 
-BracketPair FindBracketPair(std::vector<std::string> &tokens) {
-	BracketPair bp;
-	std::vector<std::string>::iterator itTok = std::find(tokens.begin(), tokens.end(), "(");
-	bp.itBracket = tokens.end();
-	bp.itEndBracket = tokens.end();
-	if (itTok != tokens.end()) {
-		bp.itBracket = itTok;
+BracketPair FindBracketPair(Tokens &tokens) {
+	const Tokens::iterator itBracket = std::find(tokens.begin(), tokens.end(), "(");
+	if (itBracket != tokens.end()) {
 		size_t nest = 0;
-		while (itTok != tokens.end()) {
+		for (Tokens::iterator itTok = itBracket; itTok != tokens.end(); ++itTok) {
 			if (*itTok == "(") {
 				nest++;
 			} else if (*itTok == ")") {
 				nest--;
 				if (nest == 0) {
-					bp.itEndBracket = itTok;
-					return bp;
+					return { itBracket, itTok };
 				}
 			}
-			++itTok;
 		}
 	}
-	bp.itBracket = tokens.end();
-	return bp;
+	return { tokens.end(), tokens.end() };
 }
 
 void highlightTaskMarker(StyleContext &sc, LexAccessor &styler,
@@ -691,8 +686,8 @@ public:
 	constexpr static int MaskActive(int style) noexcept {
 		return style & ~inactiveFlag;
 	}
-	void EvaluateTokens(std::vector<std::string> &tokens, const SymbolTable &preprocessorDefinitions);
-	std::vector<std::string> Tokenize(const std::string &expr) const;
+	void EvaluateTokens(Tokens &tokens, const SymbolTable &preprocessorDefinitions);
+	Tokens Tokenize(const std::string &expr) const;
 	bool EvaluateExpression(const std::string &expr, const SymbolTable &preprocessorDefinitions);
 };
 
@@ -776,14 +771,14 @@ Sci_Position SCI_METHOD LexerCPP::WordListSet(int n, const char *wl) {
 void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int initStyle, IDocument *pAccess) {
 	LexAccessor styler(pAccess);
 
-	CharacterSet setOKBeforeRE(CharacterSet::setNone, "([{=,:;!%^&*|?~+-");
-	CharacterSet setCouldBePostOp(CharacterSet::setNone, "+-");
+	const CharacterSet setOKBeforeRE(CharacterSet::setNone, "([{=,:;!%^&*|?~+-");
+	const CharacterSet setCouldBePostOp(CharacterSet::setNone, "+-");
 
-	CharacterSet setDoxygen(CharacterSet::setAlpha, "$@\\&<>#{}[]");
+	const CharacterSet setDoxygen(CharacterSet::setAlpha, "$@\\&<>#{}[]");
 
 	setWordStart = CharacterSet(CharacterSet::setAlpha, "_", true);
 
-	CharacterSet setInvalidRawFirst(CharacterSet::setNone, " )\\\t\v\f\n");
+	const CharacterSet setInvalidRawFirst(CharacterSet::setNone, " )\\\t\v\f\n");
 
 	if (options.identifiersAllowDollars) {
 		setWordStart.Add('$');
@@ -833,7 +828,8 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 	if (!options.updatePreprocessor)
 		ppDefineHistory.clear();
 
-	std::vector<PPDefinition>::iterator itInvalid = std::find_if(ppDefineHistory.begin(), ppDefineHistory.end(),
+	const std::vector<PPDefinition>::iterator itInvalid = std::find_if(
+		ppDefineHistory.begin(), ppDefineHistory.end(),
 		[lineCurrent](const PPDefinition &p) noexcept { return p.line >= lineCurrent; });
 	if (itInvalid != ppDefineHistory.end()) {
 		ppDefineHistory.erase(itInvalid, ppDefineHistory.end());
@@ -950,7 +946,7 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 					} else if (keywords4.InList(s)) {
 						sc.ChangeState(SCE_C_GLOBALCLASS|activitySet);
 					} else {
-						int subStyle = classifierIdentifiers.ValueFor(s);
+						const int subStyle = classifierIdentifiers.ValueFor(s);
 						if (subStyle >= 0) {
 							sc.ChangeState(subStyle|activitySet);
 						}
@@ -1083,7 +1079,7 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 					if (!(IsASpace(sc.ch) || (sc.ch == 0))) {
 						sc.ChangeState(SCE_C_COMMENTDOCKEYWORDERROR|activitySet);
 					} else if (!keywords3.InList(s + 1) && !keywords3.InList(s)) {
-						int subStyleCDKW = classifierDocKeyWords.ValueFor(s+1);
+						const int subStyleCDKW = classifierDocKeyWords.ValueFor(s+1);
 						if (subStyleCDKW >= 0) {
 							sc.ChangeState(subStyleCDKW|activitySet);
 						} else {
@@ -1100,7 +1096,7 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 						sc.GetCurrentLowered(s, sizeof(s));
 					}
 					if (!keywords3.InList(s)) {
-						int subStyleCDKW = classifierDocKeyWords.ValueFor(s + 1);
+						const int subStyleCDKW = classifierDocKeyWords.ValueFor(s + 1);
 						if (subStyleCDKW >= 0) {
 							sc.ChangeState(subStyleCDKW | activitySet);
 						} else {
@@ -1333,11 +1329,11 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 						if (sc.Match("ifdef") || sc.Match("ifndef")) {
 							const bool isIfDef = sc.Match("ifdef");
 							const int startRest = isIfDef ? 5 : 6;
-							std::string restOfLine = GetRestOfLine(styler, sc.currentPos + startRest + 1, false);
-							bool foundDef = preprocessorDefinitions.find(restOfLine) != preprocessorDefinitions.end();
+							const std::string restOfLine = GetRestOfLine(styler, sc.currentPos + startRest + 1, false);
+							const bool foundDef = preprocessorDefinitions.find(restOfLine) != preprocessorDefinitions.end();
 							preproc.StartSection(isIfDef == foundDef);
 						} else if (sc.Match("if")) {
-							std::string restOfLine = GetRestOfLine(styler, sc.currentPos + 2, true);
+							const std::string restOfLine = GetRestOfLine(styler, sc.currentPos + 2, true);
 							const bool ifGood = EvaluateExpression(restOfLine, preprocessorDefinitions);
 							preproc.StartSection(ifGood);
 						} else if (sc.Match("else")) {
@@ -1431,7 +1427,7 @@ void SCI_METHOD LexerCPP::Lex(Sci_PositionU startPos, Sci_Position length, int i
 						} else if (sc.Match("undef")) {
 							if (options.updatePreprocessor && preproc.IsActive()) {
 								const std::string restOfLine = GetRestOfLine(styler, sc.currentPos + 5, false);
-								std::vector<std::string> tokens = Tokenize(restOfLine);
+								Tokens tokens = Tokenize(restOfLine);
 								if (tokens.size() >= 1) {
 									const std::string key = tokens[0];
 									preprocessorDefinitions.erase(key);
@@ -1587,7 +1583,7 @@ void SCI_METHOD LexerCPP::Fold(Sci_PositionU startPos, Sci_Position length, int
 	}
 }
 
-void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTable &preprocessorDefinitions) {
+void LexerCPP::EvaluateTokens(Tokens &tokens, const SymbolTable &preprocessorDefinitions) {
 
 	// Remove whitespace tokens
 	tokens.erase(std::remove_if(tokens.begin(), tokens.end(), OnlySpaceOrTab), tokens.end());
@@ -1602,7 +1598,7 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 					tokens.erase(tokens.begin() + i + 1, tokens.begin() + i + 3);
 				} else if (((i+3)<tokens.size()) && (tokens[i+3] == ")")) {
 					// defined(<identifier>)
-					SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i+2]);
+					const SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i+2]);
 					if (it != preprocessorDefinitions.end()) {
 						val = "1";
 					}
@@ -1613,7 +1609,7 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 				}
 			} else {
 				// defined <identifier>
-				SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i+1]);
+				const SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i+1]);
 				if (it != preprocessorDefinitions.end()) {
 					val = "1";
 				}
@@ -1631,14 +1627,14 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 	for (size_t i = 0; (i<tokens.size()) && (iterations < maxIterations);) {
 		iterations++;
 		if (setWordStart.Contains(tokens[i][0])) {
-			SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i]);
+			const SymbolTable::const_iterator it = preprocessorDefinitions.find(tokens[i]);
 			if (it != preprocessorDefinitions.end()) {
 				// Tokenize value
-				std::vector<std::string> macroTokens = Tokenize(it->second.value);
+				Tokens macroTokens = Tokenize(it->second.value);
 				if (it->second.IsMacro()) {
 					if ((i + 1 < tokens.size()) && (tokens.at(i + 1) == "(")) {
 						// Create map of argument name to value
-						std::vector<std::string> argumentNames = StringSplit(it->second.arguments, ',');
+						Tokens argumentNames = StringSplit(it->second.arguments, ',');
 						std::map<std::string, std::string> arguments;
 						size_t arg = 0;
 						size_t tok = i+2;
@@ -1658,7 +1654,8 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 
 						for (size_t iMacro = 0; iMacro < macroTokens.size();) {
 							if (setWordStart.Contains(macroTokens[iMacro][0])) {
-								std::map<std::string, std::string>::const_iterator itFind = arguments.find(macroTokens[iMacro]);
+								const std::map<std::string, std::string>::const_iterator itFind =
+									arguments.find(macroTokens[iMacro]);
 								if (itFind != arguments.end()) {
 									// TODO: Possible that value will be expression so should insert tokenized form
 									macroTokens[iMacro] = itFind->second;
@@ -1691,7 +1688,7 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 	// Find bracketed subexpressions and recurse on them
 	BracketPair bracketPair = FindBracketPair(tokens);
 	while (bracketPair.itBracket != tokens.end()) {
-		std::vector<std::string> inBracket(bracketPair.itBracket + 1, bracketPair.itEndBracket);
+		Tokens inBracket(bracketPair.itBracket + 1, bracketPair.itEndBracket);
 		EvaluateTokens(inBracket, preprocessorDefinitions);
 
 		// The insertion is done before the removal because there were failures with the opposite approach
@@ -1709,7 +1706,7 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 			int isTrue = atoi(tokens[j+1].c_str());
 			if (tokens[j] == "!")
 				isTrue = !isTrue;
-			std::vector<std::string>::iterator itInsert =
+			const Tokens::iterator itInsert =
 				tokens.erase(tokens.begin() + j, tokens.begin() + j + 2);
 			tokens.insert(itInsert, isTrue ? "1" : "0");
 		} else {
@@ -1759,7 +1756,7 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 					result = valA || valB;
 				else if (tokens[k+1] == "&&")
 					result = valA && valB;
-				std::vector<std::string>::iterator itInsert =
+				const Tokens::iterator itInsert =
 					tokens.erase(tokens.begin() + k, tokens.begin() + k + 3);
 				tokens.insert(itInsert, std::to_string(result));
 			} else {
@@ -1769,9 +1766,9 @@ void LexerCPP::EvaluateTokens(std::vector<std::string> &tokens, const SymbolTabl
 	}
 }
 
-std::vector<std::string> LexerCPP::Tokenize(const std::string &expr) const {
+Tokens LexerCPP::Tokenize(const std::string &expr) const {
 	// Break into tokens
-	std::vector<std::string> tokens;
+	Tokens tokens;
 	const char *cp = expr.c_str();
 	while (*cp) {
 		std::string word;
@@ -1811,7 +1808,7 @@ std::vector<std::string> LexerCPP::Tokenize(const std::string &expr) const {
 }
 
 bool LexerCPP::EvaluateExpression(const std::string &expr, const SymbolTable &preprocessorDefinitions) {
-	std::vector<std::string> tokens = Tokenize(expr);
+	Tokens tokens = Tokenize(expr);
 
 	EvaluateTokens(tokens, preprocessorDefinitions);
 
