@@ -24,6 +24,7 @@
 
 #include <unistd.h>
 #include <dirent.h>
+#include <pwd.h>
 
 #endif
 
@@ -34,7 +35,7 @@
 #include <io.h>
 
 #undef _WIN32_WINNT
-#define _WIN32_WINNT  0x0602
+#define _WIN32_WINNT  0x0A00
 #include <windows.h>
 #include <commctrl.h>
 
@@ -44,6 +45,7 @@
 #endif
 
 #include "GUI.h"
+#include "StringHelpers.h"
 
 #include "FilePath.h"
 
@@ -107,25 +109,39 @@ void FilePath::Init() noexcept {
 	fileName.clear();
 }
 
+#ifdef _WIN32
+
+namespace {
+
+// Encapsulate Win32 CompareStringW
+[[nodiscard]] int Compare(const GUI::gui_string &a, const GUI::gui_string &b) noexcept {
+	return ::CompareStringW(LOCALE_SYSTEM_DEFAULT, NORM_IGNORECASE,
+		a.c_str(), static_cast<int>(a.length()),
+		b.c_str(), static_cast<int>(b.length()));
+}
+
+}
+
+#endif
+
 bool FilePath::operator==(const FilePath &other) const noexcept {
 	return SameNameAs(other);
 }
 
 bool FilePath::operator<(const FilePath &other) const noexcept {
-	return fileName < other.fileName;
-}
-
-bool FilePath::SameNameAs(const GUI::gui_char *other) const noexcept {
-#ifdef WIN32
-	return CSTR_EQUAL == CompareString(LOCALE_SYSTEM_DEFAULT, NORM_IGNORECASE,
-					   fileName.c_str(), -1, other, -1);
+#ifdef _WIN32
+	return CSTR_LESS_THAN == Compare(fileName, other.fileName);
 #else
-	return fileName == other;
+	return fileName < other.fileName;
 #endif
 }
 
 bool FilePath::SameNameAs(const FilePath &other) const noexcept {
-	return SameNameAs(other.fileName.c_str());
+#ifdef _WIN32
+	return CSTR_EQUAL == Compare(fileName, other.fileName);
+#else
+	return fileName == other.fileName;
+#endif
 }
 
 bool FilePath::IsSet() const noexcept {
@@ -154,8 +170,15 @@ bool FilePath::IsAbsolute() const noexcept {
 
 bool FilePath::IsRoot() const noexcept {
 #ifdef WIN32
-	if ((fileName[0] == pathSepChar) && (fileName[1] == pathSepChar) && (fileName.find(pathSepString, 2) == GUI::gui_string::npos))
-		return true; // UNC path like \\server
+	if (fileName.length() >= 2 && (fileName[0] == pathSepChar) && (fileName[1] == pathSepChar)) {
+		// Starts with "\\" so could be UNC \\server or \\server\share
+		const size_t posSep = fileName.find(pathSepChar, 2);
+		if (posSep == GUI::gui_string::npos)
+			return true; // No \ after initial \\, UNC path like \\server
+		const size_t posSepLast = fileName.rfind(pathSepChar);
+		// Possibly UNC share like \\server\share - only 1 pathSepChar after \\ at start
+		return posSepLast == posSep;
+	}
 	return (fileName.length() == 3) && (fileName[1] == ':') && (fileName[2] == pathSepChar);
 #else
 	return fileName == "/";
@@ -213,7 +236,7 @@ FilePath FilePath::Extension() const {
 
 FilePath FilePath::Directory() const {
 	if (IsRoot()) {
-		return FilePath(fileName.c_str());
+		return FilePath(fileName);
 	} else {
 		size_t lenDirectory = fileName.rfind(pathSepChar);
 		if (lenDirectory != GUI::gui_string::npos) {
@@ -312,6 +335,19 @@ FilePath FilePath::NormalizePath() const {
 	return FilePath(absPathString);
 }
 
+GUI::gui_string FilePath::RelativePathTo(FilePath filePath) const {
+	// Only handles simple case where filePath is in this directory or a subdirectory
+	GUI::gui_string relPath = filePath.fileName;
+	if (!fileName.empty() && StartsWith(relPath, fileName)) {
+		relPath = relPath.substr(fileName.length());
+		if (!relPath.empty()) {
+			// Remove directory separator
+			relPath.erase(0, 1);
+		}
+	}
+	return relPath;
+}
+
 /**
  * Take a filename or relative path and put it at the end of the current path.
  * If the path is absolute, return the same path.
@@ -342,6 +378,10 @@ FilePath FilePath::GetWorkingDirectory() {
 #endif
 	if (pdir) {
 		GUI::gui_string gswd(pdir);
+#if defined(_MSC_VER)
+// free is the only way to return the memory from getcwd
+#pragma warning(suppress: 26408)
+#endif
 		free(pdir);
 		// In Windows, getcwd returns a trailing backslash
 		// when the CWD is at the root of a disk, so remove it
@@ -357,6 +397,21 @@ bool FilePath::SetWorkingDirectory() const noexcept {
 	return chdir(AsInternal()) == 0;
 }
 
+FilePath FilePath::UserHomeDirectory() {
+#if defined(_WIN32)
+	return _wgetenv(GUI_TEXT("USERPROFILE"));
+#elif defined (__APPLE__)
+	// Normally sandboxed so $HOME points to sandbox directory not user home
+	struct passwd *pw = getpwuid(getuid());
+	if (!pw) {
+		return {};
+	}
+	return pw->pw_dir;
+#else
+	return getenv("HOME");
+#endif
+}
+
 void FilePath::List(FilePathSet &directories, FilePathSet &files) const {
 #ifdef WIN32
 	FilePath wildCard(*this, GUI_TEXT("*.*"));
