@@ -48,8 +48,7 @@ public:
 	void Set(FilePath const &directory, FilePath const &name);
 	void SetDirectory(FilePath const &directory);
 	virtual void Init() noexcept;
-	bool SameNameAs(const GUI::gui_char *other) const noexcept;
-	bool SameNameAs(const FilePath &other) const noexcept;
+	[[nodiscard]]bool SameNameAs(const FilePath &other) const noexcept;
 	bool operator==(const FilePath &other) const noexcept;
 	bool operator<(const FilePath &other) const noexcept;
 	bool IsSet() const noexcept;
@@ -66,8 +65,10 @@ public:
 	void FixName();
 	FilePath AbsolutePath() const;
 	FilePath NormalizePath() const;
+	GUI::gui_string RelativePathTo(FilePath filePath) const;
 	static FilePath GetWorkingDirectory();
 	bool SetWorkingDirectory() const noexcept;
+	static FilePath UserHomeDirectory();
 	void List(FilePathSet &directories, FilePathSet &files) const;
 	FILE *Open(const GUI::gui_char *mode) const noexcept;
 	std::string Read() const;
