@@ -89,6 +89,13 @@ void Buffer::Init() {
 	doc.reset();
 }
 
+void Buffer::SetTimeFromFile() {
+	fileModTime = file.ModifiedTime();
+	fileModLastAsk = fileModTime;
+	documentModTime = fileModTime;
+	failedSave = false;
+}
+
 void Buffer::DocumentModified() noexcept {
 	documentModTime = time(nullptr);
 }
@@ -122,6 +129,33 @@ void Buffer::AbandonAutomaticSave() {
 	}
 }
 
+constexpr Buffer::FutureDo operator&(Buffer::FutureDo a, Buffer::FutureDo b) noexcept {
+	return static_cast<Buffer::FutureDo>(static_cast<int>(a) & static_cast<int>(b));
+}
+
+constexpr Buffer::FutureDo operator|(Buffer::FutureDo a, Buffer::FutureDo b) noexcept {
+	return static_cast<Buffer::FutureDo>(static_cast<int>(a) | static_cast<int>(b));
+}
+
+constexpr Buffer::FutureDo operator~(Buffer::FutureDo a) noexcept {
+	return static_cast<Buffer::FutureDo>(~static_cast<int>(a));
+}
+
+void Buffer::ScheduleFinishSave() noexcept {
+	isDirty = false;
+	failedSave = false;
+	// Need to make writable and set save point when next receive focus.
+	futureDo = futureDo | FutureDo::finishSave;
+}
+
+bool Buffer::FinishSave() noexcept {
+	if ((futureDo & FutureDo::finishSave) != FutureDo::finishSave) {
+		return false;
+	}
+	futureDo = futureDo & ~(FutureDo::finishSave);
+	return true;
+}
+
 void Buffer::CancelLoad() {
 	// Complete any background loading
 	if (pFileWorker && pFileWorker->IsLoading()) {
@@ -133,7 +167,11 @@ void Buffer::CancelLoad() {
 
 BufferList::BufferList() : current(0), stackcurrent(0), stack(0), buffers(0), length(0), lengthVisible(0), initialised(false) {}
 
-void BufferList::Allocate(int maxSize) {
+BufferIndex BufferList::size() const noexcept {
+	return static_cast<BufferIndex>(buffers.size());
+}
+
+void BufferList::Allocate(BufferIndex maxSize) {
 	length = 1;
 	lengthVisible = 1;
 	current = 0;
@@ -142,7 +180,7 @@ void BufferList::Allocate(int maxSize) {
 	stack[0] = 0;
 }
 
-int BufferList::Add() {
+BufferIndex BufferList::Add() {
 	if (length < size()) {
 		length++;
 	}
@@ -154,28 +192,28 @@ int BufferList::Add() {
 	return lengthVisible - 1;
 }
 
-int BufferList::GetDocumentByWorker(const FileWorker *pFileWorker) const {
+BufferIndex BufferList::GetDocumentByWorker(const FileWorker *pFileWorker) const {
 	for (int i = 0; i < length; i++) {
 		if (buffers[i].pFileWorker.get() == pFileWorker) {
 			return i;
 		}
 	}
-	return -1;
+	return bufferInvalid;
 }
 
-int BufferList::GetDocumentByName(const FilePath &filename, bool excludeCurrent) {
+BufferIndex BufferList::GetDocumentByName(const FilePath &filename, bool excludeCurrent) {
 	if (!filename.IsSet()) {
-		return -1;
+		return bufferInvalid;
 	}
-	for (int i = 0; i < length; i++) {
+	for (BufferIndex i = 0; i < length; i++) {
 		if ((!excludeCurrent || i != current) && buffers[i].file.SameNameAs(filename)) {
 			return i;
 		}
 	}
-	return -1;
+	return bufferInvalid;
 }
 
-void BufferList::RemoveInvisible(int index) {
+void BufferList::RemoveInvisible(BufferIndex index) {
 	assert(!GetVisible(index));
 	if (index == current) {
 		RemoveCurrent();
@@ -191,7 +229,7 @@ void BufferList::RemoveInvisible(int index) {
 void BufferList::RemoveCurrent() {
 	// Delete and move up to fill gap.
 	buffers[current].CompleteLoading();
-	for (int i = current; i < length - 1; i++) {
+	for (BufferIndex i = current; i < length - 1; i++) {
 		buffers[i] = std::move(buffers[i + 1]);
 	}
 
@@ -215,7 +253,7 @@ void BufferList::RemoveCurrent() {
 	MoveToStackTop(current);
 }
 
-int BufferList::Current() const noexcept {
+BufferIndex BufferList::Current() const noexcept {
 	return current;
 }
 
@@ -227,13 +265,13 @@ const Buffer *BufferList::CurrentBufferConst() const {
 	return &buffers[Current()];
 }
 
-void BufferList::SetCurrent(int index) noexcept {
+void BufferList::SetCurrent(BufferIndex index) noexcept {
 	current = index;
 }
 
 void BufferList::PopStack() {
-	for (int i = 0; i < length - 1; ++i) {
-		int index = stack[i + 1];
+	for (BufferIndex i = 0; i < length - 1; ++i) {
+		BufferIndex index = stack[i + 1];
 		// adjust the index for items that will move in buffers[]
 		if (index > current)
 			--index;
@@ -241,22 +279,22 @@ void BufferList::PopStack() {
 	}
 }
 
-int BufferList::StackNext() {
+BufferIndex BufferList::StackNext() {
 	if (++stackcurrent >= length)
 		stackcurrent = 0;
 	return stack[stackcurrent];
 }
 
-int BufferList::StackPrev() {
+BufferIndex BufferList::StackPrev() {
 	if (--stackcurrent < 0)
 		stackcurrent = length - 1;
 	return stack[stackcurrent];
 }
 
-void BufferList::MoveToStackTop(int index) {
+void BufferList::MoveToStackTop(BufferIndex index) {
 	// shift top chunk of stack down into the slot that index occupies
 	bool move = false;
-	for (int i = length - 1; i > 0; --i) {
+	for (BufferIndex i = length - 1; i > 0; --i) {
 		if (stack[i] == index)
 			move = true;
 		if (move)
@@ -272,20 +310,19 @@ void BufferList::CommitStackSelection() {
 	stackcurrent = 0;
 }
 
-void BufferList::ShiftTo(int indexFrom, int indexTo) {
+void BufferList::ShiftTo(BufferIndex indexFrom, BufferIndex indexTo) {
 	// shift buffer to new place in buffers array
 	if (indexFrom == indexTo ||
 			indexFrom < 0 || indexFrom >= length ||
 			indexTo < 0 || indexTo >= length) return;
 	int step = (indexFrom > indexTo) ? -1 : 1;
 	Buffer tmp = std::move(buffers[indexFrom]);
-	int i;
-	for (i = indexFrom; i != indexTo; i += step) {
+	for (BufferIndex i = indexFrom; i != indexTo; i += step) {
 		buffers[i] = std::move(buffers[i+step]);
 	}
 	buffers[indexTo] = std::move(tmp);
 	// update stack indexes
-	for (i = 0; i < length; i++) {
+	for (BufferIndex i = 0; i < length; i++) {
 		if (stack[i] == indexFrom) {
 			stack[i] = indexTo;
 		} else if (step == 1) {
@@ -296,7 +333,7 @@ void BufferList::ShiftTo(int indexFrom, int indexTo) {
 	}
 }
 
-void BufferList::Swap(int indexA, int indexB) {
+void BufferList::Swap(BufferIndex indexA, BufferIndex indexB) {
 	// shift buffer to new place in buffers array
 	if (indexA == indexB ||
 			indexA < 0 || indexA >= length ||
@@ -348,11 +385,11 @@ bool BufferList::SavingInBackground() const {
 	return false;
 }
 
-bool BufferList::GetVisible(int index) const noexcept {
+bool BufferList::GetVisible(BufferIndex index) const noexcept {
 	return index < lengthVisible;
 }
 
-void BufferList::SetVisible(int index, bool visible) {
+void BufferList::SetVisible(BufferIndex index, bool visible) {
 	if (visible != GetVisible(index)) {
 		if (visible) {
 			if (index > lengthVisible) {
@@ -372,27 +409,7 @@ void BufferList::SetVisible(int index, bool visible) {
 	}
 }
 
-constexpr Buffer::FutureDo operator|(Buffer::FutureDo a, Buffer::FutureDo b) noexcept {
-	return static_cast<Buffer::FutureDo>(static_cast<int>(a) | static_cast<int>(b));
-}
-
-constexpr Buffer::FutureDo operator~(Buffer::FutureDo a) noexcept {
-	return static_cast<Buffer::FutureDo>(~static_cast<int>(a));
-}
-
-void BufferList::AddFuture(int index, Buffer::FutureDo fd) {
-	if (index >= 0 || index < length) {
-		buffers[index].futureDo = static_cast<Buffer::FutureDo>(buffers[index].futureDo | fd);
-	}
-}
-
-void BufferList::FinishedFuture(int index, Buffer::FutureDo fd) {
-	if (index >= 0 || index < length) {
-		buffers[index].futureDo = static_cast<Buffer::FutureDo>(buffers[index].futureDo & ~(fd));
-	}
-}
-
-void *SciTEBase::GetDocumentAt(int index) {
+void *SciTEBase::GetDocumentAt(BufferIndex index) {
 	if (index < 0 || index >= buffers.size()) {
 		return nullptr;
 	}
@@ -403,7 +420,7 @@ void *SciTEBase::GetDocumentAt(int index) {
 	return buffers.buffers[index].doc.get();
 }
 
-void SciTEBase::SwitchDocumentAt(int index, void *pdoc) {
+void SciTEBase::SwitchDocumentAt(BufferIndex index, void *pdoc) {
 	if (index < 0 || index >= buffers.size()) {
 		return;
 	}
@@ -413,8 +430,8 @@ void SciTEBase::SwitchDocumentAt(int index, void *pdoc) {
 	}
 }
 
-void SciTEBase::SetDocumentAt(int index, bool updateStack) {
-	const int currentbuf = buffers.Current();
+void SciTEBase::SetDocumentAt(BufferIndex index, bool updateStack) {
+	const BufferIndex currentbuf = buffers.Current();
 
 	if (index < 0 ||
 			index >= buffers.length ||
@@ -490,7 +507,7 @@ void SciTEBase::RestoreFolds(const std::vector<SA::Line> &folds) {
 }
 
 void SciTEBase::UpdateBuffersCurrent() {
-	const int currentbuf = buffers.Current();
+	const BufferIndex currentbuf = buffers.Current();
 
 	if ((buffers.length > 0) && (currentbuf >= 0) && (buffers.GetVisible(currentbuf))) {
 		Buffer &bufferCurrent = buffers.buffers[currentbuf];
@@ -580,7 +597,7 @@ FilePath SciTEBase::UserFilePath(const GUI::gui_char *name) {
 	return FilePath(GetSciteUserHome(), nameWithVisibility.c_str());
 }
 
-static std::string IndexPropKey(const char *bufPrefix, int bufIndex, const char *bufAppendix) {
+static std::string IndexPropKey(const char *bufPrefix, BufferIndex bufIndex, const char *bufAppendix) {
 	std::string pKey = bufPrefix;
 	pKey += '.';
 	pKey += StdStringFromInteger(bufIndex + 1);
@@ -602,9 +619,9 @@ void SciTEBase::LoadSessionFile(const GUI::gui_char *sessionName) {
 	propsSession.Clear();
 	propsSession.Read(sessionPathName, sessionPathName.Directory(), filter, nullptr, 0);
 
-	FilePath sessionFilePath = FilePath(sessionPathName).AbsolutePath();
+	const FilePath sessionFilePath = FilePath(sessionPathName).AbsolutePath();
 	// Add/update SessionPath environment variable
-	props.Set("SessionPath", sessionFilePath.AsUTF8().c_str());
+	props.SetPath("SessionPath", sessionFilePath);
 }
 
 void SciTEBase::RestoreRecentMenu() {
@@ -658,7 +675,7 @@ std::string StringFromLines(const std::vector<SA::Line> &lines) {
 void SciTEBase::RestoreFromSession(const Session &session) {
 	for (const BufferState &buffer : session.buffers)
 		AddFileToBuffer(buffer);
-	const int iBuffer = buffers.GetDocumentByName(session.pathActive);
+	const BufferIndex iBuffer = buffers.GetDocumentByName(session.pathActive);
 	if (iBuffer >= 0)
 		SetDocumentAt(iBuffer);
 }
@@ -796,8 +813,8 @@ void SciTEBase::SaveSessionFile(const GUI::gui_char *sessionName) {
 	}
 
 	if (props.GetInt("buffers") && (!defaultSession || props.GetInt("save.session"))) {
-		const int curr = buffers.Current();
-		for (int i = 0; i < buffers.lengthVisible; i++) {
+		const BufferIndex curr = buffers.Current();
+		for (BufferIndex i = 0; i < buffers.lengthVisible; i++) {
 			const Buffer &buff = buffers.buffers[i];
 			if (buff.file.IsSet() && !buff.file.IsUntitled()) {
 				std::string propKey = IndexPropKey("buffer", i, "path");
@@ -841,9 +858,9 @@ void SciTEBase::SaveSessionFile(const GUI::gui_char *sessionName) {
 		FailedSaveMessageBox(sessionPathName);
 	}
 
-	FilePath sessionFilePath = FilePath(sessionPathName).AbsolutePath();
+	const FilePath sessionFilePath = FilePath(sessionPathName).AbsolutePath();
 	// Add/update SessionPath environment variable
-	props.Set("SessionPath", sessionFilePath.AsUTF8().c_str());
+	props.SetPath("SessionPath", sessionFilePath);
 }
 
 void SciTEBase::SetIndentSettings() {
@@ -958,7 +975,7 @@ void SciTEBase::RestoreState(const Buffer &buffer, bool restoreBookmarks) {
 
 void SciTEBase::Close(bool updateUI, bool loadingSession, bool makingRoomForNew) {
 	bool closingLast = true;
-	const int index = buffers.Current();
+	const BufferIndex index = buffers.Current();
 	if ((index >= 0) && buffers.initialised) {
 		buffers.buffers[index].CancelLoad();
 	}
@@ -1043,7 +1060,7 @@ void SciTEBase::Close(bool updateUI, bool loadingSession, bool makingRoomForNew)
 }
 
 void SciTEBase::CloseTab(int tab) {
-	const int tabCurrent = buffers.Current();
+	const BufferIndex tabCurrent = buffers.Current();
 	if (tab == tabCurrent) {
 		if (SaveIfUnsure() != SaveResult::cancelled) {
 			Close();
@@ -1073,8 +1090,8 @@ void SciTEBase::CloseAllBuffers(bool loadingSession) {
 SciTEBase::SaveResult SciTEBase::SaveAllBuffers(bool alwaysYes) {
 	SaveResult choice = SaveResult::completed;
 	UpdateBuffersCurrent();
-	const int currentBuffer = buffers.Current();
-	for (int i = 0; (i < buffers.lengthVisible) && (choice != SaveResult::cancelled); i++) {
+	const BufferIndex currentBuffer = buffers.Current();
+	for (BufferIndex i = 0; (i < buffers.lengthVisible) && (choice != SaveResult::cancelled); i++) {
 		if (buffers.buffers[i].isDirty) {
 			SetDocumentAt(i);
 			if (alwaysYes) {
@@ -1092,8 +1109,8 @@ SciTEBase::SaveResult SciTEBase::SaveAllBuffers(bool alwaysYes) {
 
 void SciTEBase::SaveTitledBuffers() {
 	UpdateBuffersCurrent();
-	const int currentBuffer = buffers.Current();
-	for (int i = 0; i < buffers.lengthVisible; i++) {
+	const BufferIndex currentBuffer = buffers.Current();
+	for (BufferIndex i = 0; i < buffers.lengthVisible; i++) {
 		if (buffers.buffers[i].isDirty && !buffers.buffers[i].file.IsUntitled()) {
 			SetDocumentAt(i);
 			Save();
@@ -1103,7 +1120,7 @@ void SciTEBase::SaveTitledBuffers() {
 }
 
 void SciTEBase::Next() {
-	int next = buffers.Current();
+	BufferIndex next = buffers.Current();
 	if (++next >= buffers.lengthVisible)
 		next = 0;
 	SetDocumentAt(next);
@@ -1111,7 +1128,7 @@ void SciTEBase::Next() {
 }
 
 void SciTEBase::Prev() {
-	int prev = buffers.Current();
+	BufferIndex prev = buffers.Current();
 	if (--prev < 0)
 		prev = buffers.lengthVisible - 1;
 
@@ -1119,7 +1136,7 @@ void SciTEBase::Prev() {
 	CheckReload();
 }
 
-void SciTEBase::ShiftTab(int indexFrom, int indexTo) {
+void SciTEBase::ShiftTab(BufferIndex indexFrom, BufferIndex indexTo) {
 	buffers.ShiftTo(indexFrom, indexTo);
 	buffers.SetCurrent(indexTo);
 	BuffersMenu();
@@ -1131,16 +1148,16 @@ void SciTEBase::ShiftTab(int indexFrom, int indexTo) {
 
 void SciTEBase::MoveTabRight() {
 	if (buffers.lengthVisible < 2) return;
-	const int indexFrom = buffers.Current();
-	int indexTo = indexFrom + 1;
+	const BufferIndex indexFrom = buffers.Current();
+	BufferIndex indexTo = indexFrom + 1;
 	if (indexTo >= buffers.lengthVisible) indexTo = 0;
 	ShiftTab(indexFrom, indexTo);
 }
 
 void SciTEBase::MoveTabLeft() {
 	if (buffers.lengthVisible < 2) return;
-	const int indexFrom = buffers.Current();
-	int indexTo = indexFrom - 1;
+	const BufferIndex indexFrom = buffers.Current();
+	BufferIndex indexTo = indexFrom - 1;
 	if (indexTo < 0) indexTo = buffers.lengthVisible - 1;
 	ShiftTab(indexFrom, indexTo);
 }
@@ -1184,10 +1201,13 @@ GUI::gui_string EscapeFilePath(const FilePath &path, [[maybe_unused]]Title desti
 }
 
 GUI::gui_string AbbreviateWithTilde(const GUI::gui_string &path) {
-#if defined(GTK)
-	const GUI::gui_string_view homeDirectory = getenv("HOME");
-	if (StartsWith(path, homeDirectory)) {
-		return GUI::gui_string(GUI_TEXT("~")) + path.substr(homeDirectory.size());
+#if defined(GTK) || defined(__APPLE__)
+	FilePath homePath = FilePath::UserHomeDirectory();
+	if (homePath.IsSet()) {
+		const GUI::gui_string_view homeDirectory = homePath.AsInternal();
+		if (StartsWith(path, homeDirectory)) {
+			return GUI::gui_string(GUI_TEXT("~")) + path.substr(homeDirectory.size());
+		}
 	}
 #endif
 	return path;
@@ -1252,14 +1272,13 @@ void SciTEBase::SetBuffersMenu() {
 
 	std::vector<GUI::gui_string> tabNames;
 
-	int pos;
-	for (pos = buffers.lengthVisible; pos < bufferMax; pos++) {
+	for (BufferIndex pos = buffers.lengthVisible; pos < bufferMax; pos++) {
 		DestroyMenuItem(menuBuffers, IDM_BUFFER + pos);
 	}
 	if (buffers.size() > 1) {
 		constexpr int menuStart = 4;
 		SetMenuItem(menuBuffers, menuStart, IDM_BUFFERSEP, GUI_TEXT(""));
-		for (pos = 0; pos < buffers.lengthVisible; pos++) {
+		for (BufferIndex pos = 0; pos < buffers.lengthVisible; pos++) {
 			const int itemID = bufferCmdID + pos;
 			const GUI::gui_string entry = BufferTitle(pos, buffers.buffers[pos],
 				Title::menu, props, localiser);
@@ -1326,7 +1345,7 @@ bool SciTEBase::AddFileToBuffer(const BufferState &bufferState) {
 		opened = Open(bufferState.file, static_cast<OpenFlags>(ofForceLoad));
 		// If forced synchronous should set up position, foldState and bookmarks
 		if (opened) {
-			const int iBuffer = buffers.GetDocumentByName(bufferState.file, false);
+			const BufferIndex iBuffer = buffers.GetDocumentByName(bufferState.file, false);
 			if (iBuffer >= 0) {
 				buffers.buffers[iBuffer].file.scrollPosition = bufferState.file.scrollPosition;
 				buffers.buffers[iBuffer].file.selection = bufferState.file.selection;
@@ -2067,7 +2086,7 @@ void SciTEBase::GoMessage(int dir) {
 						bExists = true;
 					} else {
 						// Look through buffers for name match
-						for (int i = buffers.lengthVisible - 1; i >= 0; i--) {
+						for (BufferIndex i = buffers.lengthVisible - 1; i >= 0; i--) {
 							if (sourcePath.Name().SameNameAs(buffers.buffers[i].file.Name())) {
 								messagePath = buffers.buffers[i].file;
 								bExists = true;
@@ -2142,7 +2161,7 @@ void SciTEBase::GoMessage(int dir) {
 				}
 				std::replace(message.begin(), message.end(), '\t', ' ');
 				::Remove(message, std::string("\n"));
-				props.Set("CurrentMessage", message.c_str());
+				props.Set("CurrentMessage", message);
 				UpdateStatusBar(false);
 				WindowSetFocus(wEditor);
 			}
