@@ -10,10 +10,6 @@
 #include "SciTEWin.h"
 #include "DLLFunction.h"
 
-#ifndef WM_DPICHANGED
-#define WM_DPICHANGED 0x02E0
-#endif
-
 #ifndef NO_EXTENSIONS
 #include "MultiplexExtension.h"
 
@@ -263,6 +259,16 @@ SciTEWin::SciTEWin(Extension *ext) : SciTEBase(ext) {
 }
 
 SciTEWin::~SciTEWin() {
+	for (Buffer &buffer : buffers.buffers) {
+		// At this point, there should be no documents but sometimes there are
+		// which may be due to asynchronous I/O.
+		// wEditor has been closed so can't perform correct release of documents.
+		// Show debugger in this case.
+		assert(!buffer.doc);
+		// Drop ownership, leads to leak but exiting anyway.
+		buffer.doc.release();
+	}
+
 	if (hDevMode)
 		::GlobalFree(hDevMode);
 	if (hDevNames)
