@@ -276,7 +276,9 @@ bool SciTEWin::OpenDialog(const FilePath &directory, const GUI::gui_char *filesF
 	}
 	if (::GetOpenFileNameW(&ofn)) {
 		succeeded = true;
-		openFilterDefault = filters[(ofn.nFilterIndex-1)*2];
+		if (!filters.empty()) {
+			openFilterDefault = filters[(ofn.nFilterIndex - 1) * 2];
+		}
 		// if single selection then have path+file
 		if (wcslen(openName) > static_cast<size_t>(ofn.nFileOffset)) {
 			Open(openName);
@@ -456,14 +458,9 @@ void SciTEWin::Print(
 	pdlg.hDevMode = hDevMode;
 	pdlg.hDevNames = hDevNames;
 
-	// This code will not work for documents > 2GB
-
 	// See if a range has been selected
 	const SA::Span rangeSelection = GetSelection();
-	const LONG startPos = static_cast<LONG>(rangeSelection.start);
-	const LONG endPos = static_cast<LONG>(rangeSelection.end);
-
-	if (startPos == endPos) {
+	if (rangeSelection.start == rangeSelection.end) {
 		pdlg.Flags |= PD_NOSELECTION;
 	} else {
 		pdlg.Flags |= PD_SELECTION;
@@ -616,28 +613,16 @@ void SciTEWin::Print(
 		return;
 	}
 
-	LONG lengthDoc = static_cast<LONG>(wEditor.Length());
-	const LONG lengthDocMax = lengthDoc;
-	LONG lengthPrinted = 0;
+	const SA::Position lengthDocMax = wEditor.Length();
+	// PD_SELECTION -> requested to print selection.
+	const SA::Position lengthDoc = (pdlg.Flags & PD_SELECTION) ? rangeSelection.end : lengthDocMax;
+	SA::Position lengthPrinted = (pdlg.Flags & PD_SELECTION) ? rangeSelection.start : 0;
 
-	// Requested to print selection
-	if (pdlg.Flags & PD_SELECTION) {
-		if (startPos > endPos) {
-			lengthPrinted = endPos;
-			lengthDoc = startPos;
-		} else {
-			lengthPrinted = startPos;
-			lengthDoc = endPos;
-		}
-
-		if (lengthPrinted < 0)
-			lengthPrinted = 0;
-		if (lengthDoc > lengthDocMax)
-			lengthDoc = lengthDocMax;
-	}
+	assert(lengthPrinted >= 0);
+	assert(lengthDoc <= lengthDocMax);
 
 	// We must subtract the physical margins from the printable area
-	Sci_RangeToFormat frPrint {};
+	Sci_RangeToFormatFull frPrint {};
 	frPrint.hdc = hdc;
 	frPrint.hdcTarget = hdc;
 	frPrint.rc.left = rectMargins.left - rectPhysMargins.left;
@@ -697,7 +682,7 @@ void SciTEWin::Print(
 		frPrint.chrg.cpMin = lengthPrinted;
 		frPrint.chrg.cpMax = lengthDoc;
 
-		lengthPrinted = static_cast<LONG>(wEditor.FormatRange(printPage, &frPrint));
+		lengthPrinted = wEditor.FormatRangeFull(printPage, &frPrint);
 
 		if (printPage) {
 			if (footerFormat.size()) {
@@ -839,7 +824,7 @@ public:
 
 };
 
-static void FillComboFromProps(HWND combo, PropSetFile &props) {
+static void FillComboFromProps(HWND combo, const PropSetFile &props) {
 	const char *key = nullptr;
 	const char *val = nullptr;
 	if (props.GetFirst(key, val)) {
@@ -1270,15 +1255,15 @@ BOOL SciTEWin::GrepMessage(HWND hDlg, UINT message, WPARAM wParam) {
 				return FALSE;
 			}
 			findWhat = dlg.ItemTextU(IDFINDWHAT);
-			props.Set("find.what", findWhat.c_str());
+			props.Set("find.what", findWhat);
 			InsertFindInMemory();
 
 			std::string files = dlg.ItemTextU(IDFILES);
-			props.Set("find.files", files.c_str());
+			props.Set("find.files", files);
 			memFiles.Insert(files);
 
 			std::string directory = dlg.ItemTextU(IDDIRECTORY);
-			props.Set("find.directory", directory.c_str());
+			props.Set("find.directory", directory);
 			memDirectory.Insert(directory);
 
 			wholeWord = dlg.Checked(IDWHOLEWORD);
@@ -1370,10 +1355,9 @@ void SciTEWin::FindInFiles() {
 
 	std::string directory = props.GetString("find.in.directory");
 	if (directory.length()) {
-		props.Set("find.directory", directory.c_str());
+		props.Set("find.directory", directory);
 	} else {
-		FilePath findInDir = filePath.Directory();
-		props.Set("find.directory", findInDir.AsUTF8().c_str());
+		props.SetPath("find.directory", filePath.Directory());
 	}
 	wFindInFiles = CreateParameterisedDialog(TEXT("Grep"), GrepDlg);
 	wFindInFiles.Show();
@@ -1604,9 +1588,9 @@ void SciTEWin::ParamGrab() {
 		HWND hDlg = HwndOf(wParameters);
 		Dialog dlg(hDlg);
 		for (int param = 0; param < maxParam; param++) {
-			std::string paramVal = GUI::UTF8FromString(dlg.ItemTextG(IDPARAMSTART + param));
-			std::string paramText = StdStringFromInteger(param + 1);
-			props.Set(paramText.c_str(), paramVal.c_str());
+			const std::string paramVal = GUI::UTF8FromString(dlg.ItemTextG(IDPARAMSTART + param));
+			const std::string paramText = StdStringFromInteger(param + 1);
+			props.Set(paramText, paramVal);
 		}
 		UpdateStatusBar(true);
 	}
